<?php
namespace DsbNext\Controllers;;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;


/**
 * Class prepares parameters to generate BIRT reports by returning them to a URL
 * 
 * @author Grazielle Ferreira Antunes
 */
class DashboardReport extends \Zeedhi\Framework\Controller\Report{
    
    protected $reportService;
    protected $entityManager;
    protected $birtStrategy;
    protected $environment;
    
    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * 
     * @param object $reportService - Class of zeedhi required for the operation of BIRT reports.
     * @param object $entityManager - The data persists in the database
     * @param object $birtStrategy - Class of zeedhi required for the operation of BIRT reports.
     * @param object $environment - Allows access to session data
     * 
     * @return void
     * 
     * @access public
     * 
     * @author Grazielle Ferreira Antunes
     */
    public function __construct ($reportService, $entityManager, $birtStrategy, $environment) {
        $this->reportService       = $reportService;
        $this->entityManager        = $entityManager;
        $this->birtStrategy        = $birtStrategy;
        $this->environment         = $environment;
    }
    
    /**
     * Maps available reports and their respective parameters that 
     * will be received by BIRT to generate the report
     * 
     * @author Grazielle Ferreira Antunes
     */
    protected $reportMapping = array (
        'DIASESTOQUEGO' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        "P_DATAINI"    => "P_DATAINI",
                        "P_DATAFIN"    => "P_DATAFIN",
                        "P_CDOPERADOR" => "P_CDOPERADOR",
                        "P_NRORG"      => "P_NRORG"
                    )
            )
    );
    
    /**
     * Prepare the parameters for mapping the report including and/or 
     * changing the required parameters in the request row
     * and set the report format in birtStrategy.
     * 
     * @param Request $request – Object that receives data from the caller.
     * @param Response $response –  Object that sends back data to the caller.
     * 
     * @access public
     * 
     * @author Grazielle Ferreira Antunes
     */ 
   /* public function openReport(DTO\Request\Row $request, DTO\Response $response) {
        
    }*/
    
    public function openReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $dateIni = strtotime($row['P_DATAINI']);
        $dateIniFormat = date("d/m/Y", $dateIni);
        
        $dateFin = strtotime($row['P_DATAFIN']);
        $dateFinFormat = date("d/m/Y", $dateFin);
        
        $parametersRow = array();
        $parametersRow['P_NRORG'] = $this->environment->getNrorg();
        $parametersRow['P_CDOPERADOR'] = $this->environment->getCdOperador();
        $parametersRow['P_DATAINI'] = $dateIniFormat;
        $parametersRow['P_DATAFIN'] = $dateFinFormat;

        $this->birtStrategy->setReportFormat($row['__format']);
        $reportName = $row['__report_name'];
        $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow, true);
        $response->addMessage(new DTO\Response\Message($birtURL));
    }
}  