import { Metadata, Http } from '@zeedhi/core';
import { Modal, ModalService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class AfApprovalTrackingModalController {
  private afApprovalTrackingModal!: Modal;

  public async createAfApprovalTrackingModal() {
    this.afApprovalTrackingModal = await ModalService.createFromJson('/modals/afApprovalTrackingModal', true);
  }
  
  public destroyAfApprovalTrackingModal() {
    this.afApprovalTrackingModal?.destroy();
  }
  
  public async openAfApprovalTrackingModal({ component, row, column }) {
    const gridRoute = component.children[0].gridRoute;
    const dtMes = row.DTPROGENTAF.split(' ')[0];
    await this.afApprovalTrackingModal.show();
    const gridGroup = Metadata.getInstance<TekGrid>('AfApprovalTrackingGrid');
    gridGroup.title = `${column.label} - ${dtMes}`;
    
    let queryString = 'requestType=FilterData';
    queryString += `&INICIOMES=${dtMes}`;
    queryString += `&FIMMES=${dtMes}`;
    queryString += `&route=${column.name}`;
    
    Http.get(`/${gridRoute}?${queryString}`).then(({ data }) => {
      gridGroup.datasource.updateData(data.dataset.AfApprovalTrackingGrid);
    });
  }

  public closeAfApprovalTrackingModal() {
    this.afApprovalTrackingModal.hide();
  }
}
